@@ -4,9 +4,8 @@
     Copyright (C) 2005 R.E.Wolff@BitWizard.nl
 
     This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    it under the terms of the GNU General Public License version 2 as 
+    published by the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -59,6 +58,7 @@ typedef struct in6_addr ip_t;
 typedef struct in_addr ip_t;
 #endif
 
+extern int enablempls;
 extern int dns;
 extern int use_dns;
 
